/*
 * Enamel.java
 *
 * Created on October 17, 2006, 4:19 PM
 *
 */

package com.schwarcz.enamels.model;

import java.io.Serializable;
import java.util.List;
import javax.persistence.*;

/**
 * Entity class Enamel
 * 
 * @author Carl
 */
@Entity

@NamedQueries(value = {
    @NamedQuery(name="Enamel.findAll", query="SELECT e FROM Enamel e ORDER BY e.id"),
    
    @NamedQuery(name="Enamel.findRange", query="SELECT object(e) from Enamel e WHERE e.id >= :minAka and e.id <= :maxAka ORDER BY e.id")
    }

)

public class Enamel implements Serializable {

    @Id
    @Column(name="aka", nullable=false, length=5)
    private String id;
    private Integer year;
    private String title;
    private String descript;
    private String dimensions;
    private String collection;
    private Integer saleYear;
    private Integer salePrice;
    private String saleNote;
    private String image1;
    private String image2;
    private String image3;
    
    
    /**
     * Publication references (through <code>Citations</code> table).  
     * Publication owns the relationship
     */
    @ManyToMany(mappedBy="enamels", fetch=FetchType.EAGER)
    private List<Publication> publications;
    
    @ManyToMany(mappedBy="enamels", fetch=FetchType.LAZY)
    private List<Exhibition> exhibitions;
        
    /** Creates a new instance of Enamel */
    public Enamel() {
    }

    /**
     * Gets the id of this Enamel.
     * @return the id
     */
    public String getId() {
        return this.id;
    }

    /**
     * Sets the id of this Enamel to the specified value.
     * @param id the new id
     */
     public void setId(String id) {
        this.id = id;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.getId() != null ? this.getId().hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Enamel.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Enamel object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Enamel)) {
            return false;
        }
        Enamel other = (Enamel)object;
        if (this.getId() != other.getId() && (this.getId() == null || !this.getId().equals(other.getId()))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "com.schwarcz.enamels.model.Enamel[id=" + getId() + 
                ", " + getYear() +
                ", " + getTitle() + 
                ", " + getDescript() + "]";
    }
 

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescript() {
        return descript;
    }

    public void setDescript(String descript) {
        this.descript = descript;
    }

    public String getDimensions() {
        return dimensions;
    }

    public void setDimensions(String dimensions) {
        this.dimensions = dimensions;
    }

    public String getCollection() {
        return collection;
    }

    public void setCollection(String collection) {
        this.collection = collection;
    }

    public Integer getSaleYear() {
        return saleYear;
    }

    public void setSaleYear(Integer saleYear) {
        this.saleYear = saleYear;
    }

    public Integer getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Integer salePrice) {
        this.salePrice = salePrice;
    }

    public String getSaleNote() {
        return saleNote;
    }

    public void setSaleNote(String saleNote) {
        this.saleNote = saleNote;
    }

    public String getImage1() {
        return image1;
    }

    public void setImage1(String image1) {
        this.image1 = image1;
    }

    public String getImage2() {
        return image2;
    }

    public void setImage2(String image2) {
        this.image2 = image2;
    }

    public String getImage3() {
        return image3;
    }

    public void setImage3(String image3) {
        this.image3 = image3;
    }

    public List<Publication> getPublications() {
        return publications;
    }

    public void setPublications(List<Publication> publications) {
        this.publications = publications;
    }

    public List<Exhibition> getExhibitions() {
        return exhibitions;
    }

    public void setExhibitions(List<Exhibition> exhibitions) {
        this.exhibitions = exhibitions;
    }
    
}
