/*
 * Publication.java
 *
 * Created on October 21, 2006, 5:15 PM
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package com.schwarcz.enamels.model;

import java.io.Serializable;
import javax.persistence.*;
import java.util.List;

/**
 * Entity class Publication
 * 
 * @author Carl
 */
@Entity
public class Publication implements Serializable {
    
    /**
     * Primary key - publication ID
     */
    @Id
    private String id;
    
    /**
     * Description of the publication
     */
    private String descript;
    
    /**
     * Year of publication
     */
    private Integer year;
    
    private String changedBy;
    
    
    /**
     * The enamels referenced in the publication.
     * The join table is "citation" where "pubId references this publication
     * and "pieceAka" references the enamel.
     */
    @ManyToMany(fetch=FetchType.EAGER)
    @JoinTable(name="citation", 
        joinColumns={@JoinColumn(name="pubId")},
        inverseJoinColumns={@JoinColumn(name="pieceAka")})
    private List<Enamel> enamels;
    
    /** Creates a new instance of Publication */
    public Publication() {
    }

    /**
     * Gets the id of this Publication.
     * @return the id
     */
    public String getId() {
        return this.id;
    }

    /**
     * Sets the id of this Publication to the specified value.
     * @param id the new id
     */
    public void setId(String id) {
        this.id = id;
    }

    /**
     * Returns a hash code value for the object.  This implementation computes 
     * a hash code value based on the id fields in this object.
     * @return a hash code value for this object.
     */
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (this.getId() != null ? this.getId().hashCode() : 0);
        return hash;
    }

    /**
     * Determines whether another object is equal to this Publication.  The result is 
     * <code>true</code> if and only if the argument is not null and is a Publication object that 
     * has the same id field values as this object.
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Publication)) {
            return false;
        }
        Publication other = (Publication)object;
        if (this.getId() != other.getId() && (this.getId() == null || !this.getId().equals(other.getId()))) return false;
        return true;
    }

    /**
     * Returns a string representation of the object.  This implementation constructs 
     * that representation based on the id fields.
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return "com.schwarcz.enamels.model.Publication[id=" + getId() + "]";
    }

    public String getDescript() {
        return descript;
    }

    public void setDescript(String descript) {
        this.descript = descript;
    }

    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }

    public String getChangedBy() {
        return changedBy;
    }

    public void setChangedBy(String changedBy) {
        this.changedBy = changedBy;
    }

    public List<Enamel> getEnamels() {
        return enamels;
    }

    public void setEnamels(List<Enamel> enamels) {
        this.enamels = enamels;
    }
    
}
